@@ -5,7 +5,7 @@
 # --------------------------------------------------------------------------------------
 
 
-from oauth2client.service_account import ServiceAccountCredentials
+from google.oauth2.service_account import Credentials
 
 
 def _service_account_creds_from_secret(service_account_secret):
@@ -18,19 +18,20 @@ def _service_account_creds_from_secret(service_account_secret):
 	:param service_account_secret: Service Account Secret Key from Firebase Console.
 	:type service_account_secret: dict | str
 	:return: Service Account Credentials
-	:rtype: ServiceAccountCredentials
+	:rtype: :class:`~google.oauth2.service_account.Credentials`
 	"""
 
 	credentials = None
 	scopes = [
 		'https://www.googleapis.com/auth/firebase.database',
+		"https://www.googleapis.com/auth/datastore",
 		'https://www.googleapis.com/auth/userinfo.email',
 		"https://www.googleapis.com/auth/cloud-platform"
 	]
 
 	if type(service_account_secret) is str:
-		credentials = ServiceAccountCredentials.from_json_keyfile_name(service_account_secret, scopes)
+		credentials = Credentials.from_service_account_file(service_account_secret, scopes=scopes)
 	if type(service_account_secret) is dict:
-		credentials = ServiceAccountCredentials.from_json_keyfile_dict(service_account_secret, scopes)
+		credentials = Credentials.from_service_account_info(service_account_secret, scopes=scopes)
 
 	return credentials
